==> haskell-network-simple-0.4.5-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-simple
version:              0.4.5
visibility:           public
id:                   network-simple-0.4.5-Eqrqmmvk6XqE9n4rL0GMDv
key:                  network-simple-0.4.5-Eqrqmmvk6XqE9n4rL0GMDv
license:              BSD-3-Clause
copyright:            Copyright (c) Renzo Carbonara 2013-2019
maintainer:           renλren.zone
author:               Renzo Carbonara
homepage:             https://github.com/k0001/network-simple
synopsis:             Simple network sockets usage patterns.
description:
    This module exports functions that abstract simple network socket
    usage patterns.

    See the @changelog.md@ file in the source distribution to learn about any
    important changes between versions.

category:             Network
abi:                  c1095df5baa07478902506f58c1ce7d5
exposed:              True
exposed-modules:      Network.Simple.TCP
hidden-modules:       Network.Simple.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-simple-0.4.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-simple-0.4.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-simple-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-simple
hs-libraries:         HSnetwork-simple-0.4.5-Eqrqmmvk6XqE9n4rL0GMDv
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-7d91dIi13MzEkgRQe6YDcO
    network-bsd-2.8.1.0-HuhWvJ2Aj668JMsZYWYhww
    safe-exceptions-0.1.7.4-ES7S1HwS0lOI4lBBxEPT7M
    socks-0.6.1-97WciPgRxCr9gvCTTbNhrl transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-network-simple/html/network-simple.haddock

haddock-html:         /usr/share/doc/haskell-network-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-simple-0.4.5-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-simple
version:              0.4.5
visibility:           public
id:                   network-simple-0.4.5-KSX22zia9009Dh1TZc1ANp
key:                  network-simple-0.4.5-KSX22zia9009Dh1TZc1ANp
license:              BSD-3-Clause
copyright:            Copyright (c) Renzo Carbonara 2013-2019
maintainer:           renλren.zone
author:               Renzo Carbonara
homepage:             https://github.com/k0001/network-simple
synopsis:             Simple network sockets usage patterns.
description:
    This module exports functions that abstract simple network socket
    usage patterns.

    See the @changelog.md@ file in the source distribution to learn about any
    important changes between versions.

category:             Network
abi:                  5b14354529ec48cc859dfb02a8d3e3a7
exposed:              True
exposed-modules:      Network.Simple.TCP
hidden-modules:       Network.Simple.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-simple-0.4.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-simple-0.4.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-simple-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-simple
hs-libraries:         HSnetwork-simple-0.4.5-KSX22zia9009Dh1TZc1ANp
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-24l6wfZeDaoIo68scGYLPE
    network-bsd-2.8.1.0-DyOP2bNOalaKKOPdVrgWOJ
    safe-exceptions-0.1.7.4-9LcGMfMqJ04DZxvpKtRT4V
    socks-0.6.1-6XG80o8rjRtDZZc5Vh8yVi transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-network-simple/html/network-simple.haddock

haddock-html:         /usr/share/doc/haskell-network-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
